% Clear the workspace
clear;

bitstringlength = 104;
popsize = 50;
pmut = 1/bitstringlength;

o.verbose = 1;
o.MaxFunEvals = 1000;

% Call the evolutionary algorithm for the fBinRosenbrock objective function.
[x, fx, hist] = minEA(...
    @fBinRosenbrock, {}, ...
    @iniBinUniform, {popsize, bitstringlength}, ...
    @selTournament, {popsize}, ...
    @xoverBinUniform, {}, ...
    @mutBinSwitchBit, {pmut}, ...
    @repTournamentOldVsNew, {}, ...
    o);


% Plot the history of the optimization
[ax,h1,h2] = plotyy(hist.evals, hist.fmin, hist.evals, hist.fmed, @steplogy, @steplogy);
xlabel('evaluations');
ylabel(ax(1),'loss function - best');
ylabel(ax(2),'loss function - median');

% Plot the contour plot of the evaluation function and the trajectory of
% the algorithm in the 2D real space.
x = tranBinToRealRosenbrock(hist.x);
xf = -2.048:0.05:2.048;
[xx,yy] = meshgrid(xf,xf);
ff = fRealRosenbrock([xx(:) yy(:)]);
ff = reshape(ff,size(xx));
figure;
contour(xf,xf,ff,32); hold on;
plot(x(:,1), x(:,2), 'bx-');